pub struct Row<'a, Message, Theme = Theme, Renderer = Renderer> { /* private fields */ }applet only.Expand description
A container that distributes its contents horizontally.
Example
use iced::widget::{button, row};
#[derive(Debug, Clone)]
enum Message {
// ...
}
fn view(state: &State) -> Element<'_, Message> {
row![
"I am to the left!",
button("I am in the middle!"),
"I am to the right!",
].into()
}Implementations
Sourceimpl<'a, Message, Theme, Renderer> Row<'a, Message, Theme, Renderer>where
Renderer: Renderer,
impl<'a, Message, Theme, Renderer> Row<'a, Message, Theme, Renderer>where
Renderer: Renderer,
Sourcepub fn with_capacity(capacity: usize) -> Self
pub fn with_capacity(capacity: usize) -> Self
Creates a Row with the given capacity.
Sourcepub fn with_children(
children: impl IntoIterator<Item = Element<'a, Message, Theme, Renderer>>,
) -> Self
pub fn with_children( children: impl IntoIterator<Item = Element<'a, Message, Theme, Renderer>>, ) -> Self
Creates a Row with the given elements.
Sourcepub fn from_vec(children: Vec<Element<'a, Message, Theme, Renderer>>) -> Self
pub fn from_vec(children: Vec<Element<'a, Message, Theme, Renderer>>) -> Self
Creates a Row from an already allocated Vec.
Keep in mind that the Row will not inspect the Vec, which means
it won’t automatically adapt to the sizing strategy of its contents.
If any of the children have a Length::Fill strategy, you will need to
call Row::width or Row::height accordingly.
Sourcepub fn spacing(self, amount: impl Into<Pixels>) -> Self
pub fn spacing(self, amount: impl Into<Pixels>) -> Self
Sets the horizontal spacing between elements.
Custom margins per element do not exist in iced. You should use this method instead! While less flexible, it helps you keep spacing between elements consistent.
Sourcepub fn align_y(self, align: impl Into<Vertical>) -> Self
pub fn align_y(self, align: impl Into<Vertical>) -> Self
Sets the vertical alignment of the contents of the Row .
Sourcepub fn clip(self, clip: bool) -> Self
pub fn clip(self, clip: bool) -> Self
Sets whether the contents of the Row should be clipped on
overflow.
Sourcepub fn push_maybe(
self,
child: Option<impl Into<Element<'a, Message, Theme, Renderer>>>,
) -> Self
pub fn push_maybe( self, child: Option<impl Into<Element<'a, Message, Theme, Renderer>>>, ) -> Self
Adds an element to the Row, if Some.
Sourcepub fn extend(
self,
children: impl IntoIterator<Item = Element<'a, Message, Theme, Renderer>>,
) -> Self
pub fn extend( self, children: impl IntoIterator<Item = Element<'a, Message, Theme, Renderer>>, ) -> Self
Extends the Row with the given children.